<?php

/**
 * Create Recipe Custom Post Type
 */ 
add_action( 'init', 'register_my_culinary_recipe' );
  
function register_my_culinary_recipe() {
    $labels = array(
        'name'               => _x( 'Recipes', 'culinary_recipes' ),
        'singular_name'      => _x( 'Recipe', 'culinary_recipes' ),
        'add_new'            => _x( 'Add New', 'culinary_recipes' ),
        'add_new_item'       => _x( 'Add New Recipe', 'culinary_recipes' ),
        'edit_item'          => _x( 'Edit Recipe', 'culinary_recipes' ),
        'new_item'           => _x( 'New Recipe', 'culinary_recipes' ),
        'view_item'          => _x( 'View Recipe', 'culinary_recipes' ),
        'search_items'       => _x( 'Search Recipes', 'culinary_recipes' ),
        'not_found'          => _x( 'No Recipes found', 'culinary_recipes' ),
        'not_found_in_trash' => _x( 'No recipes found in Trash', 'culinary_recipes' ),
        'parent_item_colon'  => '',
        'menu_name'          => _x( 'Recipes', 'culinary_recipes' )
    );
	$args = array(
        'labels'              => $labels,
        'public'              => true,
        'publicly_queryable'  => true,
        'show_ui'             => true,
        'show_in_menu'        => true,
        'show_in_nav_menus'   => true,
        'exclude_from_search' => false,
        'hierarchical'        => false,
        'has_archive'         => true,
        'rewrite'             => array('slug' => 'recipe')
	);
	register_post_type( 'my_culinary_recipe', $args );  
}

/**
 * Initialize Metabox Class
 */ 
function be_initialize_cmb_meta_boxes() {
    if ( !class_exists( 'cmb_Meta_Box' ) ) {
		require_once( 'lib/metabox/init.php' );
    }
}
add_action( 'init', 'be_initialize_cmb_meta_boxes', 9999 );

/**
 * Define new field type - number
 * see https://github.com/jaredatch/Custom-Metaboxes-and-Fields-for-WordPress/wiki/Adding-your-own-field-types for more information
 */ 
add_action( 'cmb_render_number', 'rrh_cmb_render_number', 10, 2 );

function rrh_cmb_render_number( $field, $meta ) {
	echo '<input type="number" min="0" max="60" class="cmb_text_inline" name="', $field['id'], '" id="', $field['id'], '" value="', '' !== $meta ? $meta : $field['std'], '" />','<p class="cmb_metabox_description">', $field['desc'], '</p>';
}	

add_filter( 'cmb_validate_number', 'rrh_cmb_validate_number' );

function rrh_cmb_validate_number( $new ) {
    return (int)$new;
}

/**
 * Define meta boxes
 */ 
$prefix = 'mcr_'; // Prefix for all fields

function mcr_create_metaboxes( $meta_boxes ) {
	global $prefix;
    $meta_boxes[] = array(
        'id'         => 'recipe-data',
        'title'      => 'Culinary Recipe',
        'pages'      => array('my_culinary_recipe'),
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true,
        'fields'     => array(
            //TITLE - TEXT
            array(
                'name' => __( 'Recipe Title', 'culinary_recipes' ),
                'id'   => $prefix . 'name',
                'type' => 'text',
            ),
            //RECIPE TYPE - TEXT
            array(
                'name' => __( 'Recipe Type', 'culinary_recipes' ),
                'desc' => __( 'The type of dish: for example, appetizer, entree, dessert, etc.', 'culinary_recipes' ),
                'id'   => $prefix . 'type',
                'type' => 'text_medium',
            ),
            // IMAGE UPLOAD
            array(
                'name'    => 'Recipe Image',
                'desc'    => 'Image of the dish being prepared.',
                'id'      => $prefix . 'image',
                'type'    => 'file',
                'save_id' => false, // save ID using true
                'allow'   => array('url', 'attachment') // limit to just attachments with array( 'attachment' )
            ),
            //SUMMARY - TEXT
            array(
                'name' => __( 'Summary', 'culinary_recipes' ),
                'desc' => __( 'A short summary describing the dish.', 'culinary_recipes' ),
                'id'   => $prefix . 'summary',
                'type' => 'text',
            ),
            //INGREDIENTS - TEXTAREA
            array(
                'name' => __( 'Ingredients', 'culinary_recipes' ),
                'desc' => __( 'Put each ingredient in seaprate line.', 'culinary_recipes' ),
                'id'   => $prefix . 'ingredients',
                'type' => 'textarea',
            ),
            //DIRECTIONS - TEXTAREA
            array(
                'name' => __( 'Instructions', 'culinary_recipes' ),
                'desc' => __( 'Put each instruction in seaprate line.', 'culinary_recipes' ),
                'id'   => $prefix . 'instructions',
                'type' => 'textarea',
            ),
            //YIELD - TEXT
            array(
                'name' => __( 'Yield', 'culinary_recipes' ),
                'desc' => __( 'Enter the number of servings or number of people served', 'culinary_recipes' ),
                'id'   => $prefix . 'yield',
                'type' => 'text_medium',
            ),
            //PREP TIME - TITLE
            array(
                'name' => __( 'Prep time', 'culinary_recipes' ),
                'desc' => __( 'How long does it take to prep?', 'culinary_recipes' ),
                'type' => 'title',
                'id'   => $prefix . 'prep_title'
            ),
            //PREP TIME HOURS - NUMBER
            array(
                'name' => __( 'Hours', 'culinary_recipes' ),
                'id'   => $prefix . 'prep_time_hours',
                'type' => 'number',
                'std'  => '0',
            ),
            //PREP TIME MINUTES- NUMBER
            array(
                'name' => __( 'Minutes', 'culinary_recipes' ),
                'id'   => $prefix . 'prep_time_minutes',
                'type' => 'number',
                'std'  => '0',
            ),
            //COOK TIME - TITLE
            array(
                'name' => __( 'Cooking time', 'culinary_recipes' ),
                'desc' => __( 'Total time of cooking, baking etc.', 'culinary_recipes' ),
                'type' => 'title',
                'id'   => $prefix . 'coking_title'
            ),
            //COOKING TIME - TEXT
            array(
                'name' => __( 'Hours', 'culinary_recipes' ),
                'id'   => $prefix . 'cook_time_hours',
                'type' => 'number',
                'std'  => '0',
            ),
            //COOKING TIME - TEXT
            array(
                'name' => __( 'Minutes', 'culinary_recipes' ),
                'id'   => $prefix . 'cook_time_minutes',
                'type' => 'number',
                'std'  => '0',
            )
        )
    );

	return $meta_boxes;
 }

add_filter( 'cmb_meta_boxes' , 'mcr_create_metaboxes' );


/**
 *
 */
function mcr_time($type = 'prep', $format = null) {

	global $post;

	$hours = get_post_meta($post->ID,'mcr_'.$type.'_time_hours',true);
	$minutes = get_post_meta($post->ID,'mcr_'.$type.'_time_minutes',true);
	
	$time = '';
	
	if ($format == 'iso') {

		if ($hours > 0) {
			$time = 'PT'.$hours.'H';
			if($minutes > 0) {
				$time .= $minutes.'M';
			}
		}
		else {
			$time = 'PT'.$minutes.'M';
		}

	}else{

		if ($hours > 0) {
			if ($hours == 1) {
				$time = $hours.' hour ';			
			}else{
				$time = $hours.' hrs ';			
			}
			
			if($minutes > 0) {
				$time .= $minutes.' mins';
			}
		}
		else {
			$time = $minutes.' mins';
		}
	
	}

	return $time;
}

function mcr_total_time($format = null) {
	global $post;

	$prep_hours = get_post_meta($post->ID,'mcr_prep_time_hours',true);
	$prep_minutes = get_post_meta($post->ID,'mcr_prep_time_minutes',true);
	$cook_hours = get_post_meta($post->ID,'mcr_cook_time_hours',true);
	$cook_minutes = get_post_meta($post->ID,'mcr_cook_time_minutes',true);

	$total_minutes = ($prep_hours + $cook_hours)*60 + $prep_minutes + $cook_minutes;
	$hours = 0;
	$minutes = 0;
	
	if($total_minutes >= 60) {
		$hours = floor($total_minutes / 60);
		$minutes = $total_minutes - ($hours * 60);
	}else{
		$minutes = $total_minutes;
	}
	$total_time = '';
	
	if ($format == 'iso') {
		if ($hours > 0 ) {
			$total_time = 'PT'.$hours.'H';
			if($minutes > 0) {
				$total_time .= $minutes.'M';
			}
		}
		else {
			$total_time = 'PT'.$minutes.'M';
		}
	}else{
		if ($hours > 0 ) {	
			if ($hours == 1) {
				$total_time = $hours.' hour ';
			}else{
				$total_time = $hours.' hrs ';
			}
			if($minutes > 0) {
				$total_time .= $minutes.' mins';
			}
		}
		else {
			$total_time = $minutes.' mins';
		}
	}
	
	return $total_time;
}

function mcr_list_items($type = '') {
	global $post;
	
	if(get_post_meta($post->ID, 'mcr_'. $type, true)) {
		$get_items = get_post_meta($post->ID, 'mcr_'. $type, true);
		$items = explode("\r", $get_items);
		$list = '';
	}else {
		return;
	}
	
	if($type=='ingredients'){
		$list .= '<ul>';
		foreach($items as $item){
			$list .= '<li><span itemprop="ingredients">' . trim($item) . '</span></li>';
		}
		$list .= '</ul>';
	}elseif($type=='instructions'){
		$list .= '<ol itemprop="recipeInstructions">';
		foreach($items as $item){
			$list .= '<li>' . trim($item) . '</li>';
		}	
		$list .= '</ol>';
	}else{
		$list .= 'Invalid list type.';
	}

	return $list;
}

function mcr_display_recipe($content) {
	global $post;
	$recipe = '';

	if(is_singular( 'my_culinary_recipe' ) ){
		$recipe .= '<div class="recipe">';
			$recipe .= '<div itemscope itemtype="http://schema.org/Recipe" >';
				$recipe .= '<h2 itemprop="name">'. get_post_meta($post->ID,'mcr_name',true) .'</h2>';
				$recipe .= '<img class="alignright" itemprop="image" src="'. get_post_meta($post->ID,'mcr_image',true) .'" />'; 
				$recipe .= '<span class="mcr_meta"><b>Recipe type:</b> <time itemprop="recipeCategory">'. get_post_meta($post->ID,'mcr_type',true) .'</time></span>';
				$recipe .= '<span class="mcr_meta"><b>Yield:</b> <span itemprop="recipeYield">'. get_post_meta($post->ID,'mcr_yield',true) .'</span></span>';
				$recipe .= '<span class="mcr_meta"><b>Prep time:</b> <time content="'. mcr_time('prep','iso') .'" itemprop="prepTime">'. mcr_time('prep') .'</time></span>';
				$recipe .= '<span class="mcr_meta"><b>Cook time:</b> <time content="'. mcr_time('cook','iso') .'" itemprop="cookTime">'. mcr_time('cook') .'</time></span>';
				$recipe .= '<span class="mcr_meta"><b>Total time:</b> <time content="'. mcr_total_time('iso') .'" itemprop="totalTime">'. mcr_total_time() .'</time></span>';
				$recipe .= '</br>';
				$recipe .= '<hr />';
				$recipe .= '<span itemprop="description">'. get_post_meta($post->ID,'mcr_summary',true) .'</span><br />';
				$recipe .= '<h3>Ingredients:</h3> '. mcr_list_items('ingredients');
				$recipe .= '<h3>Directions:</h3> '. mcr_list_items('instructions');
				$recipe .= '<span class="mcr_meta">Published on <time itemprop="datePublished" content="'. get_the_date('Y-m-d') .'">'. get_the_date('F j, Y') .'</time></span>';
				$recipe .= '<span class="mcr_meta">by <span itemprop="author">'. get_the_author() .'</span></span>';
			$recipe .= '</div>';
		$recipe .= '</div>';
	}
	
	return $content . $recipe;
}

add_filter('the_content', 'mcr_display_recipe', 1);